@@ -2,10 +2,10 @@
 #'
 #' @description Computes estimates, with confidence intervals, of the population size and probability of capture from the number of fish removed in k-, 3-, or 2-passes in a closed population.
 #'
-#' @details The main function computes the estimates and associated standard errors, if possible, for the initial population size, No, and probability of capture, p, for seven methods chosen with \code{method=}.  The possible methods are:
+#' @details The main function computes the estimates and associated standard errors, if possible, for the initial population size, No, and probability of capture, p, for seven methods chosen with \code{method=}. The possible methods are:
 #'  \itemize{
-#'    \item \code{method="CarleStrub"}: The general weighted k-pass estimator proposed by Carle and Strub (1978).  This function iteratively solves for No in equation 7 of Carle and Strub (1978).
-#'    \item \code{method="Zippin"}: The general k-pass estimator generally attributed to Zippin.  This function iteratively solves for No in bias corrected version of equation 3 (page 622) of Carle and Strub (1978).  These results are not yet trustworthy.
+#'    \item \code{method="CarleStrub"}: The general weighted k-pass estimator proposed by Carle and Strub (1978). This function iteratively solves for No in equation 7 of Carle and Strub (1978).
+#'    \item \code{method="Zippin"}: The general k-pass estimator generally attributed to Zippin. This function iteratively solves for No in bias corrected version of equation 3 (page 622) of Carle and Strub (1978). These results are not yet trustworthy (see Testing section below).
 #'    \item \code{method="Seber3"}: The special case for k=3 estimator shown in equation 7.24 of Seber(2002).
 #'    \item \code{method="Seber2"}: The special case for k=2 estimator shown on page 312 of Seber(2002).
 #'    \item \code{method="RobsonRegier2"}: The special case for k=2 estimator shown by Robson and Regier (1968).
@@ -13,25 +13,25 @@
 #'    \item \code{method="Schnute"}: The likelihood method of Schnute (1983) for the model that has a different probability of capture for the first sample but a constant probability of capture for all ensuing samples..
 #'  }
 #'
-#' Confidence intervals for the first five methods are computed using standard large-sample normal distribution theory.  Note that the confidence intervals for the 2- and 3-pass special cases are only approximately correct if the estimated population size is greater than 200.  If the estimated population size is between 50 and 200 then a 95\% CI behaves more like a 90\% CI.
+#' Confidence intervals for the first five methods are computed using standard large-sample normal distribution theory. Note that the confidence intervals for the 2- and 3-pass special cases are only approximately correct if the estimated population size is greater than 200. If the estimated population size is between 50 and 200 then a 95\% CI behaves more like a 90\% CI.
 #' 
-#' Confidence intervals for the last two methods use likelihood ratio theory as described in Schnute (1983) and are only produced for the No parameter.  Standard errors are not produced with the Moran or Schnute methods..
+#' Confidence intervals for the last two methods use likelihood ratio theory as described in Schnute (1983) and are only produced for the No parameter. Standard errors are not produced with the Moran or Schnute methods..
 #'
-#' In the Carle Strub method, if the resultant No estimate is equal to the sum of the catches (T) then the estimate of No that is returned will be the sum of the catches.  In this instance, and if the \dQuote{Seber} method of computing the standard error is used, then the SE will not be estimable and the confidence intervals can not be constructed.
+#' In the Carle Strub method, if the resultant No estimate is equal to the sum of the catches (T) then the estimate of No that is returned will be the sum of the catches. In this instance, and if the \dQuote{Seber} method of computing the standard error is used, then the SE will not be estimable and the confidence intervals can not be constructed.
 #'
 #' @param catch A numerical vector of catch at each pass.
-#' @param method A single string that identifies the removal method to use.  See details.
+#' @param method A single string that identifies the removal method to use. See details.
 #' @param alpha A single numeric value for the alpha parameter in the CarleStrub method (default is \code{1}).
 #' @param beta A single numeric value for the beta parameter in the CarleStrub method (default is \code{1}).
 #' @param CS.se A single string that identifies whether the SE in the CarleStrub method should be computed according to Seber or Zippin.
 #' @param object An object saved from \code{removal()}.
-#' @param parm A specification of which parameters are to be given confidence intervals, either a vector of numbers or a vector of names.  If missing, all parameters are considered.
+#' @param parm A specification of which parameters are to be given confidence intervals, either a vector of numbers or a vector of names. If missing, all parameters are considered.
 #' @param level Note used, but her for compatibility with generic \code{confint} function.
-#' @param conf.level A single number representing the level of confidence to use for constructing confidence intervals.  This is sent in the main \code{removal} function rather than \code{confint}.
+#' @param conf.level A single number representing the level of confidence to use for constructing confidence intervals. This is sent in the main \code{removal} function rather than \code{confint}.
 #' @param just.ests A logical that indicates whether just the estimates (\code{=TRUE}) or the return list (\code{=FALSE}; default; see below) is returned.
 #' @param verbose A logical that indicates whether descriptive labels should be printed from \code{summary} and if certain warnings are shown with \code{confint}.
 #' @param digits A single numeric that controls the number of decimals in the output from \code{summary} and \code{confint}.
-#' @param Tmult A single numeric that will be multiplied by the total catch in all samples to set the upper value for the range of population sizes when minimizing the log-likelihood and creating confidence intervals for the Moran and Schnute method.  Large values are much slower to compute, but too low of a value can result in missing the best estimate.  A warning is issued if too low of a value is suspected.
+#' @param Tmult A single numeric that will be multiplied by the total catch in all samples to set the upper value for the range of population sizes when minimizing the log-likelihood and creating confidence intervals for the Moran and Schnute method. Large values are much slower to compute, but too low of a value can result in missing the best estimate. A warning is issued if too low of a value is suspected.
 #' @param \dots Additional arguments for methods.
 #'
 #' @return A vector that contains the estimates and standard errors for No and p if \code{just.ests=TRUE} or (default) a list with at least the following items:
@@ -48,7 +48,7 @@
 #'    \item Tmult The Tmult value sent by the user.
 #'  }
 #' 
-#' @section testing: The Carle-Strub method matches the examples in Carle and Strub (1978) for No, p, and the variance of No.  The Carle-Strub estimates of No and p match the examples in Cowx (1983) but the SE of No does not.  The Carle-Strub estimates of No match the results (for estimates that they did not reject) from Jones and Stockwell (1995) to within 1 individual in most instances and within 1\% for all other instances (e.g., off by 3 individuals when the estimate was 930 individuals).
+#' @section testing: The Carle-Strub method matches the examples in Carle and Strub (1978) for No, p, and the variance of No. The Carle-Strub estimates of No and p match the examples in Cowx (1983) but the SE of No does not. The Carle-Strub estimates of No match the results (for estimates that they did not reject) from Jones and Stockwell (1995) to within 1 individual in most instances and within 1\% for all other instances (e.g., off by 3 individuals when the estimate was 930 individuals).
 #' 
 #' The Seber3 results for No match the results in Cowx (1983).
 #' 
@@ -56,7 +56,7 @@
 #' 
 #' The RobsonRegier2 results for No and the SE of NO match the results in Cowx (1983)
 #' 
-#' The Zippin method results do not match the examples in Seber (2002) or Cowx (1983) because \code{removal} uses the bias-corrected version from Carle and Strub (1978) and does not use the tables in Zippin (1958).  The Zippin method is not yet trustworthy.
+#' The Zippin method results do not match the examples in Seber (2002) or Cowx (1983) because \code{removal} uses the bias-corrected version from Carle and Strub (1978) and does not use the tables in Zippin (1958). The Zippin method is not yet trustworthy.
 #' 
 #' The Moran and Schnute methods match the examples in Schnute (1983) perfectly for all point estimates and within 0.1 units for all confidence intervals.
 #'
@@ -66,21 +66,21 @@
 #'
 #' @seealso See \code{\link{depletion}} for related functionality.
 #' 
-#' @references Ogle, D.H.  2016.  \href{http://derekogle.com/IFAR}{Introductory Fisheries Analyses with R}.  Chapman & Hall/CRC, Boca Raton, FL.
+#' @references Ogle, D.H. 2016. \href{http://derekogle.com/IFAR}{Introductory Fisheries Analyses with R}. Chapman & Hall/CRC, Boca Raton, FL.
 #' 
-#' Carle, F.L. and M.R. Strub. 1978. A new method for estimating population size from removal data.  Biometrics, 34:621-630.
+#' Carle, F.L. and M.R. Strub. 1978. A new method for estimating population size from removal data. Biometrics, 34:621-630.
 #'
-#' Cowx, I.G.  1983.  Review of the methods for estimating fish population size from survey removal data.  Fisheries Management, 14:67-82.
+#' Cowx, I.G. 1983. Review of the methods for estimating fish population size from survey removal data. Fisheries Management, 14:67-82.
 #' 
-#' Moran, P.A.P.  1951.  A mathematical theory of animal trapping.  Biometrika 38:307-311.
+#' Moran, P.A.P. 1951. A mathematical theory of animal trapping. Biometrika 38:307-311.
 #'
-#' Robson, D.S., and H.A. Regier.  1968.  Estimation of population number and mortality rates.  pp. 124-158 in Ricker, W.E. (editor) Methods for Assessment of Fish Production in Fresh Waters.  IBP Handbook NO. 3 Blackwell Scientific Publications, Oxford.
+#' Robson, D.S., and H.A. Regier. 1968. Estimation of population number and mortality rates. pp. 124-158 in Ricker, W.E. (editor) Methods for Assessment of Fish Production in Fresh Waters. IBP Handbook NO. 3 Blackwell Scientific Publications, Oxford.
 #' 
-#' Schnute, J.  1983.  A new approach to estimating populations by the removal method.  Canadian Journal of Fisheries and Aquatic Sciences, 40:2153-2169.
+#' Schnute, J. 1983. A new approach to estimating populations by the removal method. Canadian Journal of Fisheries and Aquatic Sciences, 40:2153-2169.
 #'
 #' Seber, G.A.F. 2002. The Estimation of Animal Abundance. Edward Arnold, second edition (Reprint).
 #' 
-#' van Dishoeck, P.  2009.  Effects of catchability variation on performance of depletion estimators: Application to an adaptive management experiment.  Masters Thesis, Simon Fraser University.  [Was (is?) from http://rem-main.rem.sfu.ca/theses/vanDishoeckPier_2009_MRM483.pdf.]
+#' van Dishoeck, P. 2009. Effects of catchability variation on performance of depletion estimators: Application to an adaptive management experiment. Masters Thesis, Simon Fraser University. [Was (is?) from http://rem-main.rem.sfu.ca/theses/vanDishoeckPier_2009_MRM483.pdf.]
 #' 
 #' @keywords manip
 #'
@@ -303,7 +303,7 @@ iRemovalLHCI <- function(method,catch,conf.level,k,T,X,min.nlogLH,Tmult){
     #   value and then find the first and last position
     tmp <- range(which(nlogLHvals<=nlogLHcrit))
     # If the last position in the last N tried then the Ns tried were
-    #   probably not adequate.  Tell the user to up the Tmult value.
+    #   probably not adequate. Tell the user to up the Tmult value.
     if (max(tmp)==length(Ntrys) & !UCIfail) WARN("Upper confidence value is ill-formed; try increasing 'Tmult' in 'removal()'.")
     # The LCI is N in the lower position, UCI is N in the higher position.
     if (!LCIfail) LCI <- Ntrys[tmp[1]]
@@ -328,7 +328,7 @@ iLHMoran <- function(N,catch,k,T,XX) {
   Ti_hat <- cumsum(ct_hat)                          # Schnute (1983) equation 1.1
   T_hat <- Ti_hat[k]
   # negative log-likelihood (Schnute (1983) G(Z) and H(Z) (no K)
-  #   from equation 2.6).  The [catch>0] solves issues with
+  #   from equation 2.6). The [catch>0] solves issues with
   #   when a catch=0
   N*log(N)-T*log(T)-(N-T)*log(N-T_hat)-lchoose(N,T)+sum(catch[catch>0]*log(catch[catch>0]/ct_hat[catch>0]))
 }
@@ -344,15 +344,23 @@ iMoran <- function(catch,conf.level,Tmult) {
   X <- int[["X"]]
   # A check
   if (k<3) STOP("The Moran method requires at least three samples.")
-  # optimize for N
-  tmp <- stats::optimize(iLHMoran,c(T,ceiling(Tmult*T)),catch=catch,k=k,T=T,XX=X)
-  N0 <- tmp$minimum
-  p <- T/(k*N0-X)
-  # compute confidence intervals for No
-  tmpci <- iRemovalLHCI("Moran",catch,conf.level,k,T,X,tmp$objective,Tmult)  
+  if (k==3 & catch[3]==0) {
+    WARN("The Moran method will fail when the catch in the last of three samples is 0.")
+    est <- c(No=NA,No.LCI=NA,No.UCI=NA,p=NA)
+    tmp <- list(objective=NA)
+    tmpci <- list(LCImsg=NA,UCImsg=NA)
+  } else {
+    # optimize for N
+    tmp <- stats::optimize(iLHMoran,c(T,ceiling(Tmult*T)),
+                           catch=catch,k=k,T=T,XX=X)
+    N0 <- tmp$minimum
+    p <- T/(k*N0-X)
+    # compute confidence intervals for No
+    tmpci <- iRemovalLHCI("Moran",catch,conf.level,k,T,X,tmp$objective,Tmult)
+    est <- c(No=N0,No.LCI=tmpci$CI[[1]],No.UCI=tmpci$CI[[2]],p=p)
+  }
   # return list
-  list(est=c(No=N0,No.LCI=tmpci$CI[[1]],No.UCI=tmpci$CI[[2]],p=p),
-       catch=catch,min.nlogLH=tmp$objective,Tmult=Tmult,
+  list(est=est,catch=catch,min.nlogLH=tmp$objective,Tmult=Tmult,
        LCImsg=tmpci$LCImsg,UCImsg=tmpci$UCImsg,
        lbl="Moran (1951) K-Pass Removal Method")
 }
@@ -392,17 +400,23 @@ iSchnute <- function(catch,conf.level,Tmult) {
   X <- int[["X"]]
   # A check
   if (k<3) STOP("The Schnute method requires at least three samples.")
-  if (k==3 & catch[3]==0) STOP("The Schnute method will fail when the catch in the last of three samples is 0.")
-  # optimize for N
-  tmp <- stats::optimize(iLHSchnute,c(T,ceiling(Tmult*T)),catch=catch,k=k,T=T,XX=X)
-  N0 <- tmp$minimum
-  p1 <- catch[1]/N0
-  p <- (T-catch[1])/((k-1)*(N0-catch[1])-(X-(k-1)*catch[1]))
-  # compute confidence intervals for No
-  tmpci <- iRemovalLHCI("Schnute",catch,conf.level,k=k,T=T,X=X,tmp$objective,Tmult)  
+  if (k==3 & catch[3]==0) {
+    WARN("The Schnute method will fail when the catch in the last of three samples is 0.")
+    est <- c(No=NA,No.LCI=NA,No.UCI=NA,p=NA,p1=NA)
+    tmp <- list(objective=NA)
+    tmpci <- list(LCImsg=NA,UCImsg=NA)
+  } else {
+    # optimize for N
+    tmp <- stats::optimize(iLHSchnute,c(T,ceiling(Tmult*T)),catch=catch,k=k,T=T,XX=X)
+    N0 <- tmp$minimum
+    p1 <- catch[1]/N0
+    p <- (T-catch[1])/((k-1)*(N0-catch[1])-(X-(k-1)*catch[1]))
+    # compute confidence intervals for No
+    tmpci <- iRemovalLHCI("Schnute",catch,conf.level,k=k,T=T,X=X,tmp$objective,Tmult)
+    est <- c(No=N0,No.LCI=tmpci$CI[[1]],No.UCI=tmpci$CI[[2]],p=p,p1=p1)
+  }
   # return list
-  list(est=c(No=N0,No.LCI=tmpci$CI[[1]],No.UCI=tmpci$CI[[2]],p=p,p1=p1),
-       catch=catch,min.nlogLH=tmp$objective,Tmult=Tmult,
+  list(est=est,catch=catch,min.nlogLH=tmp$objective,Tmult=Tmult,
        LCImsg=tmpci$LCImsg,UCImsg=tmpci$UCImsg,
        lbl="Schnute (1983) K-Pass Removal Method w/ Non-constant Initial Catchability")
 }
@@ -428,8 +442,13 @@ iZippin <- function(catch,conf.level) {
   k <- int[["k"]]
   T <- int[["T"]]
   X <- int[["X"]]
-  # This condition is from equation 6 in Carle & Strub (1978)
-  if (X <= (((T-1)*(k-1))/2)-1) {
+  # Method does not work with all zero catches
+  if (sum(catch)==0) {
+    WARN("No catches on any pass results in Zippin model failure.")
+    # empty vector of estimates
+    tmp <- rep(NA,8)
+  } else if (X <= (((T-1)*(k-1))/2)-1) {
+    # This condition is from equation 6 in Carle & Strub (1978)
     WARN("Catch data results in Zippin model failure.")
     # empty vector of estimates
     tmp <- rep(NA,8)
